/*
 * 
 *  This file is part of Sourceprojects.org Lycia Copyright 2010 noctarius
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * 
 */
package org.sourceprojects.lycia;

import java.util.List;

import org.sourceprojects.lycia.internal.configuration.BasicXmlParserConfigurator;
import org.w3c.dom.Element;
import org.xml.sax.ContentHandler;

/**
 * Base class to extend the {@link LyciaConfigurator} chain in Lycia. Can be
 * used to enhance the capabilities of legal tags.
 * 
 * @author noctarius
 * 
 * @param <B>
 *            Type of ContextObject to use
 */
public abstract class AbstractXmlParserConfigurator<B> extends
		BasicXmlParserConfigurator<B> {

	public AbstractXmlParserConfigurator(final LyciaParser<B> xmlParser,
			final LyciaConfigurator<B> parent) {

		super(xmlParser, parent);

		if (xmlParser == null) {
			throw new NullPointerException("XmlParser instance cannot be null");
		}
	}

	@Override
	public void addTagDefinitionParser(
			final TagDefinitionParser<B> definitionParser) {
		getParentXmlParserConfigurator().addTagDefinitionParser(
				definitionParser);
	}

	@Override
	public void addTagDefinitionParser(final Object definitionParser) {
		getParentXmlParserConfigurator().addTagDefinitionParser(
				definitionParser);
	}

	@Override
	public void addTagDefinitionParsers(
			final TagDefinitionParser<B>[] definitionParsers) {

		getParentXmlParserConfigurator().addTagDefinitionParsers(
				definitionParsers);
	}

	@Override
	public void addTagDefinitionParsers(final Object[] definitionParsers) {
		getParentXmlParserConfigurator().addTagDefinitionParsers(
				definitionParsers);
	}

	@Override
	public TagDefinitionParser<B> findTagDefinitionParser(
			final QualifiedName localElement, final Element element) {

		return getParentXmlParserConfigurator().findTagDefinitionParser(
				localElement, element);
	}

	@Override
	public TagDefinitionParser<B> findTagDefinitionParser(final String tagName,
			final String namespaceURI, final Element element) {

		return getParentXmlParserConfigurator().findTagDefinitionParser(
				tagName, namespaceURI, element);
	}

	@Override
	public List<TagDefinitionParser<B>> findTagDefinitionParsers(
			final QualifiedName localElement, final Element element) {

		return getParentXmlParserConfigurator().findTagDefinitionParsers(
				localElement, element);
	}

	@Override
	public List<TagDefinitionParser<B>> findTagDefinitionParsers(
			final String tagName, final String namespaceURI,
			final Element element) {

		return getParentXmlParserConfigurator().findTagDefinitionParsers(
				tagName, namespaceURI, element);
	}

	@Override
	public GenerationStrategy getGenerationStrategy() {
		return getParentXmlParserConfigurator().getGenerationStrategy();
	}

	@Override
	public GeneratorFactory<B> getGeneratorFactory() {
		return getParentXmlParserConfigurator().getGeneratorFactory();
	}

	@Override
	public LyciaConfigurator<B> getParentXmlParserConfigurator() {
		return getParentXmlParserConfigurator()
				.getParentXmlParserConfigurator();
	}

	@Override
	public void removeTagDefinitionParser(
			final TagDefinitionParser<B> definitionParser) {

		getParentXmlParserConfigurator().removeTagDefinitionParser(
				definitionParser);
	}

	@Override
	public void removeTagDefinitionParser(final Object definitionParser) {
		getParentXmlParserConfigurator().removeTagDefinitionParser(
				definitionParser);
	}

	@Override
	public void removeTagDefinitionParsers(
			final TagDefinitionParser<B>[] definitionParsers) {

		getParentXmlParserConfigurator().removeTagDefinitionParsers(
				definitionParsers);
	}

	@Override
	public void removeTagDefinitionParsers(final Object[] definitionParsers) {
		getParentXmlParserConfigurator().removeTagDefinitionParsers(
				definitionParsers);
	}

	@Override
	public void setGenerationStrategy(
			final GenerationStrategy generationStrategy) {
		getParentXmlParserConfigurator().setGenerationStrategy(
				generationStrategy);
	}

	@Override
	public void setGeneratorFactory(final GeneratorFactory<B> generatorFactory) {
		if (getParentXmlParserConfigurator() != null) {
			getParentXmlParserConfigurator().setGeneratorFactory(
					generatorFactory);
		}
	}

	@Override
	public void addContentHandler(final ContentHandler contentHandler) {
		getParentXmlParserConfigurator().addContentHandler(contentHandler);
	}

	@Override
	public List<ContentHandler> getContentHandlers() {
		return getParentXmlParserConfigurator().getContentHandlers();
	}

	@Override
	public void removeContentHandler(final ContentHandler contentHandler) {
		getParentXmlParserConfigurator().removeContentHandler(contentHandler);
	}

}
