/*
 * 
 *  This file is part of Sourceprojects.org Lycia Copyright 2010 noctarius
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * 
 */
package org.sourceprojects.lycia;

/**
 * Interface for ParserContext implementations.<br>
 * The standard implementation of this interface returned by
 * {@link LyciaParserFactory} is generified to be able to meet users
 * requirements while parsing
 * 
 * @author noctarius
 * @since 0.0.1
 * 
 * @param <T>
 *            Type of ContextObject to use
 */
public interface ParserContext<T> {

	/**
	 * Sets the context object of type T for being available while parsing
	 * 
	 * @param contextObject
	 *            Instance of type T
	 */
	void setContextObject(T contextObject);

	/**
	 * Returns the context object of type T for being available while parsing
	 * 
	 * @return Instance of type T
	 */
	T getContextObject();

	/**
	 * Sets the state string to identify different states for parsing on same
	 * {@link TagDefinitionParser} implementations for all parsing reasons
	 * 
	 * @param parserState
	 *            String to identify a parser state
	 */
	void setParserState(String parserState);

	/**
	 * Returns the state string to identify different states of parsing on same
	 * {@link TagDefinitionParser} implementations for all parsing reasons
	 * 
	 * @return Actual state of the parser
	 */
	String getParserState();
}
