/*
 * 
 *  This file is part of Sourceprojects.org Lycia Copyright 2010 noctarius
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * 
 */
package org.sourceprojects.lycia.internal.platform.base;

import javax.xml.XMLConstants;
import javax.xml.parsers.DocumentBuilderFactory;

import org.sourceprojects.lycia.LyciaParser;
import org.sourceprojects.lycia.exceptions.LyciaInitializationException;
import org.sourceprojects.lycia.internal.platform.PlatformSchemaFactory;
import org.xml.sax.SAXException;

public class PlatformSchemaFactoryImpl<B> implements PlatformSchemaFactory<B> {

	@Override
	public void build(final DocumentBuilderFactory builderFactory,
			final LyciaParser<B> lyciaParser) {

		if (!lyciaParser.isValidatingSchema()) {
			return;
		}

		final javax.xml.validation.SchemaFactory factory = javax.xml.validation.SchemaFactory
				.newInstance(XMLConstants.W3C_XML_SCHEMA_NS_URI);

		final EntityResolverWrapper wrapper = new EntityResolverWrapper(
				lyciaParser.getResourceResolver());

		factory.setResourceResolver(wrapper);

		factory.setErrorHandler(lyciaParser.getErrorHandler());

		try {
			builderFactory.setSchema(factory.newSchema());
		} catch (final SAXException e) {
			throw new LyciaInitializationException(e);
		}
	}
}
