/*
 * 
 *  This file is part of Sourceprojects.org Lycia Copyright 2010 noctarius
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * 
 */
package org.sourceprojects.lycia.internal.validation;

import java.lang.annotation.Annotation;
import java.lang.reflect.Field;

import org.sourceprojects.lycia.LyciaParser;
import org.sourceprojects.lycia.internal.privileged.SetAccessible;
import org.w3c.dom.Element;

public class FieldValidationField<B> implements ValidationField<B> {

	private final Field field;

	FieldValidationField(final Field field) {
		this.field = field;

		SetAccessible.setAccessible(field);
	}

	@Override
	public Annotation[] getAnnotations() {
		return field.getAnnotations();
	}

	@Override
	public String getName() {
		return field.getName();
	}

	@Override
	public Object getValue(final Element element,
			final LyciaParser<B> lyciaParser) {
		return element.getAttribute(getName());
	}

	@Override
	public Class<?> getDeclaringClass() {
		return field.getDeclaringClass();
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((field == null) ? 0 : field.hashCode());
		return result;
	}

	@Override
	public boolean equals(final Object obj) {
		if (this == obj) {
			return true;
		}
		if (obj == null) {
			return false;
		}
		if (getClass() != obj.getClass()) {
			return false;
		}
		final FieldValidationField<?> other = (FieldValidationField<?>) obj;
		if (field == null) {
			if (other.field != null) {
				return false;
			}
		} else if (!field.equals(other.field)) {
			return false;
		}
		return true;
	}

	@Override
	public String toString() {
		return "FieldValidationField [field=" + field + "]";
	}

}
